==> keycloak-model-map-18.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapAuthenticationExecutionEntityDelegate.java <==
package org.keycloak.models.map.realm.entity;
public class MapAuthenticationExecutionEntityDelegate implements org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity> delegateProvider;
    public MapAuthenticationExecutionEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.ID, id).setId(id);
    }
    @Override public String getAuthenticator() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.AUTHENTICATOR).getAuthenticator();
    }
    @Override public void setAuthenticator(String authenticator) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.AUTHENTICATOR, authenticator).setAuthenticator(authenticator);
    }
    @Override public String getAuthenticatorConfig() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.AUTHENTICATOR_CONFIG).getAuthenticatorConfig();
    }
    @Override public void setAuthenticatorConfig(String authenticatorConfig) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.AUTHENTICATOR_CONFIG, authenticatorConfig).setAuthenticatorConfig(authenticatorConfig);
    }
    @Override public org.keycloak.models.AuthenticationExecutionModel.Requirement getRequirement() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.REQUIREMENT).getRequirement();
    }
    @Override public void setRequirement(org.keycloak.models.AuthenticationExecutionModel.Requirement requirement) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.REQUIREMENT, requirement).setRequirement(requirement);
    }
    @Override public Boolean isAutheticatorFlow() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.AUTHETICATOR_FLOW).isAutheticatorFlow();
    }
    @Override public void setAutheticatorFlow(Boolean autheticatorFlow) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.AUTHETICATOR_FLOW, autheticatorFlow).setAutheticatorFlow(autheticatorFlow);
    }
    @Override public String getFlowId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.FLOW_ID).getFlowId();
    }
    @Override public void setFlowId(String flowId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.FLOW_ID, flowId).setFlowId(flowId);
    }
    @Override public String getParentFlowId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.PARENT_FLOW_ID).getParentFlowId();
    }
    @Override public void setParentFlowId(String parentFlowId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.PARENT_FLOW_ID, parentFlowId).setParentFlowId(parentFlowId);
    }
    @Override public Integer getPriority() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.PRIORITY).getPriority();
    }
    @Override public void setPriority(Integer priority) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.PRIORITY, priority).setPriority(priority);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapAuthenticationExecutionEntityDelegate.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapAuthenticationExecutionEntityDelegate implements org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity, org.keycloak.models.map.common.delegate.HasDelegateProvider<org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity> {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity> delegateProvider;
    public MapAuthenticationExecutionEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    public org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity> getDelegateProvider() {
        return this.delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.ID, id).setId(id);
    }
    @Override public String getAuthenticator() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.AUTHENTICATOR).getAuthenticator();
    }
    @Override public void setAuthenticator(String authenticator) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.AUTHENTICATOR, authenticator).setAuthenticator(authenticator);
    }
    @Override public String getAuthenticatorConfig() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.AUTHENTICATOR_CONFIG).getAuthenticatorConfig();
    }
    @Override public void setAuthenticatorConfig(String authenticatorConfig) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.AUTHENTICATOR_CONFIG, authenticatorConfig).setAuthenticatorConfig(authenticatorConfig);
    }
    @Override public org.keycloak.models.AuthenticationExecutionModel.Requirement getRequirement() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.REQUIREMENT).getRequirement();
    }
    @Override public void setRequirement(org.keycloak.models.AuthenticationExecutionModel.Requirement requirement) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.REQUIREMENT, requirement).setRequirement(requirement);
    }
    @Override public Boolean isAutheticatorFlow() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.AUTHETICATOR_FLOW).isAutheticatorFlow();
    }
    @Override public void setAutheticatorFlow(Boolean autheticatorFlow) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.AUTHETICATOR_FLOW, autheticatorFlow).setAutheticatorFlow(autheticatorFlow);
    }
    @Override public String getFlowId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.FLOW_ID).getFlowId();
    }
    @Override public void setFlowId(String flowId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.FLOW_ID, flowId).setFlowId(flowId);
    }
    @Override public String getParentFlowId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.PARENT_FLOW_ID).getParentFlowId();
    }
    @Override public void setParentFlowId(String parentFlowId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.PARENT_FLOW_ID, parentFlowId).setParentFlowId(parentFlowId);
    }
    @Override public Integer getPriority() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.PRIORITY).getPriority();
    }
    @Override public void setPriority(Integer priority) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.PRIORITY, priority).setPriority(priority);
    }
}
